==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/user/messages/pl/account.php <==
<?php

return [
    '<strong>Account</strong> settings' => '<strong>Ustawienia</strong> konta',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Potwierdź</strong> twój nowy adres e-mail',
    '<strong>Permissions</strong>' => '<strong>Pozwolenia</strong>',
    '<strong>User</strong> settings' => '<strong>Ustawienia</strong> użytkownika',
    '<strong>Your</strong> profile' => '<strong>Twój</strong> profil',
    'All your personal data will be irrevocably deleted.' => 'Wszystkie Twoje dane zostaną bezpowrotnie usunięte.',
    'Are you sure that you want to delete your account?' => 'Jesteś pewien, ze chcesz usunąć konto?',
    'Blocked users' => 'Zablokowani użytkownicy',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Zmiana nazwy użytkownika może uczynić niektóre linki bezużyteczne, np stare linki do profilu.',
    'Confirm' => 'Potwierdź',
    'Current password' => 'Obecne hasło',
    'Delete account' => 'Usuń konto',
    'Do you really want to delete your icon image?' => 'Czy na pewno usunąć ikonę?',
    'Do you really want to delete your logo image?' => 'Czy na pewno usunąć logo?',
    'E-Mail' => 'E-mail',
    'E-Mail change' => 'Zmień e-mail',
    'Enter your password to continue' => 'Wpisz hasło żeby kontynuować',
    'Hello' => 'Cześć',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Tutaj możesz edytować ogólne informacje o profilu, które są widoczne na stronie O mnie na Twoim profilu,',
    'Hide introduction tour panel on dashboard' => 'Ukryj panel wprowadzenia na tablicy',
    'Invalid link! Please make sure that you entered the entire url.' => 'Nieprawidłowy link! Proszę upewnij się czy wprowadziłeś cały adres URL.',
    'Language' => 'Język',
    'Modules' => 'Moduły',
    'New E-Mail address' => 'Nowy adres e-mail',
    'New User name' => 'Nowa nazwa użytkownika',
    'Not registered users' => 'Niezarejestrowani użytkownicy',
    'Notifications' => 'Powiadomienia',
    'Other users' => 'Inni użytkownicy',
    'Password Recovery' => 'Odzyskiwanie hasła',
    'Permissions' => 'Uprawnienia',
    'Profile' => 'Profil',
    'Profile visibility' => 'Widoczność profilu',
    'Registered users only' => 'Tylko dla zarejestrowanych',
    'Save' => 'Zapisz',
    'Save profile' => 'Zapisz profil',
    'Settings' => 'Ustawienia',
    'Tags' => 'Tagi',
    'The entered e-mail address is already in use by another user.' => 'Wprowadzony adres e-mail jest już w użyciu przez innego użytkownika.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Te ustawienia pozwolą Ci ustalić których pozwoleń chcesz udzielić osobom odwiedzającym Twój indywidualny profil. Każdy użytkownik może dowolnie dostosowywać ustawienia swojego profilu.',
    'TimeZone' => 'Strefa czasowa',
    'Username has been changed' => 'Nazwa użytkownika została zmieniona',
    'Users' => 'Użytkownicy',
    'Visible for all (also unregistered users)' => 'Widoczne dla wszystkich (również nie zarejestrowanych)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Właśnie wysłaliśmy e-mail z potwierdzeniem na twój nowy adres. <br /> Proszę podążaj za instrukcjami które zawiera.',
    'You are currently the owner of following spaces:' => 'Aktualnie jesteś właścicielem tych stref:',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Wysłałeś prośbę o zmianę twojego adresu e-mail.<br />Twoim nowym adresem e-mail jest {newemail}.<br /><br /> Aby potwierdzić nowy adres e-mail proszę kliknij poniższy przycisk.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Twoja nazwa użytkownika została zmieniona. <br />Twoja nowa nazwa użytkownika to {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Musisz przekazać własność lub usunąć te strefy  zanim będziesz mógł usunąć konto.',
    'Your account cannot be deleted!' => 'Twoje konto nie może zostać usunięte!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Twój obecny adres e-mail to<b>{email}</b>. Możesz zmienić obecny adres e-mail tutaj.',
    'Your current password can be changed here.' => 'Twoje obecne hasło może zostać tu zmienione.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Twoja aktualna nazwa użytkownika to <b>{username}</b>. Tutaj możesz ją zmienić.',
    'Your e-mail address has been successfully changed to {email}.' => 'Twój adres e-mail został z powodzeniem zmieniony na {email}.',
    'Your friends' => 'Twoi znajomi',
    'Your password has been successfully changed!' => 'Twoje hasła zostało z powodzeniem zmienione!',
    'Your username has been changed' => 'Twoja nazwa użytkownika została zmieniona',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Twoja nazwa użytkownika została pomyślnie zmieniona.<br /> Wysłaliśmy Ci wiadomość e-mail z tą informacją.',
    '{attribute} "{value}" was not found!' => '{attribute} "{value}" nie zostało znalezione!',
    'You cannot use this username.' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/user/messages/pl/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => 'Ustawienia <strong>Konta</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Potwierdź</strong> twój nowy adres e-mail',
    '<strong>Permissions</strong>' => '<strong>Pozwolenia</strong>',
    '<strong>Your</strong> Account' => '<strong>Twoje</strong> Konto',
    '<strong>Your</strong> profile' => '<strong>Twój</strong> profil',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Dodaj tagi do swojego profilu, które opisują twoje zainteresowania i umiejętności. Będą widoczne tak w profilu jak i w katalogu \'Ludzie\'.',
    'All your personal data will be irrevocably deleted.' => 'Wszystkie Twoje dane zostaną bezpowrotnie usunięte.',
    'Are you sure that you want to delete your account?' => 'Jesteś pewien, ze chcesz usunąć konto?',
    'Blocked users' => 'Zablokowani użytkownicy',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Zmiana nazwy użytkownika może uczynić niektóre linki bezużyteczne, np stare linki do profilu.',
    'Confirm' => 'Potwierdź',
    'Current password' => 'Obecne hasło',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Poustawiaj własny profil. Możesz dodać taki, zmienić język interfejsu czy zablokować kłopotliwych użytkowników.',
    'Delete account' => 'Usuń konto',
    'Do you really want to delete your icon image?' => 'Czy na pewno usunąć ikonę?',
    'Do you really want to delete your logo image?' => 'Czy na pewno usunąć logo?',
    'E-Mail' => 'E-mail',
    'E-Mail change' => 'Zmień e-mail',
    'Enter your password to continue' => 'Wpisz hasło żeby kontynuować',
    'General' => 'Ogólne',
    'Hello' => 'Cześć',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Tutaj możesz edytować ogólne informacje o profilu, które są widoczne na stronie O mnie na Twoim profilu,',
    'Hide introduction tour panel on dashboard' => 'Ukryj panel wprowadzenia na tablicy',
    'Hide my online status' => 'Ukryj mój status online',
    'Invalid link! Please make sure that you entered the entire url.' => 'Nieprawidłowy link! Proszę upewnij się czy wprowadziłeś cały adres URL.',
    'Language' => 'Język',
    'Markdown Editor Mode' => 'Tryb edytora Markdown',
    'Modules' => 'Moduły',
    'New E-Mail address' => 'Nowy adres e-mail',
    'New User name' => 'Nowa nazwa użytkownika',
    'Not registered users' => 'Niezarejestrowani użytkownicy',
    'Notifications' => 'Powiadomienia',
    'Other users' => 'Inni użytkownicy',
    'Password Recovery' => 'Odzyskiwanie hasła',
    'Permissions' => 'Uprawnienia',
    'Plain' => 'Czysty',
    'Profile' => 'Profil',
    'Profile Tags' => 'Tagi profilowe',
    'Profile visibility' => 'Widoczność profilu',
    'Registered users only' => 'Tylko dla zarejestrowanych',
    'Rich Text' => 'Wzbogacony tekst',
    'Save' => 'Zapisz',
    'Save profile' => 'Zapisz profil',
    'The entered e-mail address is already in use by another user.' => 'Wprowadzony adres e-mail jest już w użyciu przez innego użytkownika.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Te ustawienia pozwolą Ci ustalić których pozwoleń chcesz udzielić osobom odwiedzającym Twój indywidualny profil. Każdy użytkownik może dowolnie dostosowywać ustawienia swojego profilu.',
    'TimeZone' => 'Strefa czasowa',
    'Username has been changed' => 'Nazwa użytkownika została zmieniona',
    'Users' => 'Użytkownicy',
    'Visible for all (also unregistered users)' => 'Widoczne dla wszystkich (również nie zarejestrowanych)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Właśnie wysłaliśmy e-mail z potwierdzeniem na twój nowy adres. <br /> Proszę podążaj za instrukcjami które zawiera.',
    'You are currently the owner of following spaces:' => 'Aktualnie jesteś właścicielem tych stref:',
    'You cannot use this username.' => 'Nie możesz używać tej nazwy użytkownika',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Wysłałeś prośbę o zmianę twojego adresu e-mail.<br />Twoim nowym adresem e-mail jest {newemail}.<br /><br /> Aby potwierdzić nowy adres e-mail proszę kliknij poniższy przycisk.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Twoja nazwa użytkownika została zmieniona. <br />Twoja nowa nazwa użytkownika to {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Musisz przekazać własność lub usunąć te strefy  zanim będziesz mógł usunąć konto.',
    'Your account cannot be deleted!' => 'Twoje konto nie może zostać usunięte!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Twój obecny adres e-mail to<b>{email}</b>. Możesz zmienić obecny adres e-mail tutaj.',
    'Your current password can be changed here.' => 'Twoje obecne hasło może zostać tu zmienione.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Twoja aktualna nazwa użytkownika to <b>{username}</b>. Tutaj możesz ją zmienić.',
    'Your e-mail address has been successfully changed to {email}.' => 'Twój adres e-mail został z powodzeniem zmieniony na {email}.',
    'Your friends' => 'Twoi znajomi',
    'Your password has been successfully changed!' => 'Twoje hasła zostało z powodzeniem zmienione!',
    'Your username has been changed' => 'Twoja nazwa użytkownika została zmieniona',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Twoja nazwa użytkownika została pomyślnie zmieniona.<br /> Wysłaliśmy Ci wiadomość e-mail z tą informacją.',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
];
